lc3_encode

Function lc3_encode 

pub unsafe extern "C" fn lc3_encode(
    encoder: lc3_encoder_t,
    fmt: lc3_pcm_format,
    pcm: *const c_void,
    stride: c_int,
    nbytes: c_int,
    out: *mut c_void,
) -> c_int
Encode a frame encoder Handle of the encoder fmt PCM input format pcm, stride Input PCM samples, and count between two consecutives nbytes Target size, in bytes, of the frame out Output buffer of nbytes size return 0: On success -1: Wrong parameters