lc3_hr_setup_encoder

Function lc3_hr_setup_encoder 

pub unsafe extern "C" fn lc3_hr_setup_encoder(
    hrmode: bool,
    dt_us: c_int,
    sr_hz: c_int,
    sr_pcm_hz: c_int,
    mem: *mut c_void,
) -> lc3_encoder_t
Setup encoder hrmode Enable High-Resolution mode (48000 and 96000 sample rates) dt_us Frame duration in us, 2500, 5000, 7500 or 10000 sr_hz Sample rate in Hz, 8000, 16000, 24000, 32000, 48000 or 96000 sr_pcm_hz Input sample rate, downsampling option of input, or 0 mem Encoder memory space, aligned to pointer type return Encoder as an handle, NULL on bad parameters

The sr_pcm_hz parameter is a downsampling option of PCM input, the value 0 fallback to the sample rate of the encoded stream sr_hz. When used, sr_pcm_hz is intended to be higher or equal to the encoder sample rate sr_hz. The size of the context needed, given by lc3_hr_encoder_size() will be set accordingly to sr_pcm_hz.