pub unsafe extern "C" fn lc3_decode(
decoder: lc3_decoder_t,
in_: *const c_void,
nbytes: c_int,
fmt: lc3_pcm_format,
pcm: *mut c_void,
stride: c_int,
) -> c_intExpand description
Decode a frame decoder Handle of the decoder in, nbytes Input bitstream, and size in bytes, NULL performs PLC fmt PCM output format pcm, stride Output PCM samples, and count between two consecutives return 0: On success 1: PLC operated -1: Wrong parameters